@@ -695,12 +695,13 @@ class BaseExperiment:
             pickle.dump(model, open(ckpt_path, 'wb'))
         elif isinstance(model, pl.LightningModule):
             trainer.save_checkpoint(ckpt_path)
+        self._create_folder(f"{self.log_path}/jsonlogs")
         metadata_dir = f"{self.log_path}/jsonlogs/{model.__class__.__name__}/{model_metadata}"
         self._create_folder(metadata_dir)
         jsonlog_version = len(os.listdir(metadata_dir))
         model_metadata = self.set_model_metadata(model, self.get_hparams(model))
         jsonlog_folder = f"{metadata_dir}/version_{jsonlog_version}"
-        self._create_folder(jsonlog_folder) # necessary for sklearn-based models
+        self._create_folder(jsonlog_folder)
         jsonlog_path = f"{jsonlog_folder}/validation_metrics.json"
         # saving results
         if isinstance(model, BaseEstimator):
@@ -855,11 +856,7 @@ class BaseExperiment:
             :obj:LightningModule or None: The best checkpoint(or the path if fetch_only_dir is True) as per the validation metric you defined in the argument. Returns None if there are no saved checkpoints
 
         """
-        try:
-            jsonlogdir = f"{self.log_path}/jsonlogs"
-        except:
-            logger.info("Nothing has been saved yet.")
-            return None
+        jsonlogdir = f"{self.log_path}/jsonlogs"
         if not mode:
             if val_metric == 'val/loss':
                 mode = 'min'
