@@ -606,7 +606,7 @@ class BaseProject:
                     if idx < n_data + 1:
                         img = fig.add_subplot(rows, cols, idx)
                         img.imshow(self.X[sampling_idx][idx-1])
-                        img.set_title('label : {labels_to_show[idx-1]}')
+                        img.set_title(f'label : {labels_to_show[idx-1]}')
             plt.show()
             plt.savefig(f"{img_dir}/image_samples.png")       
 
